@@ -2,17 +2,16 @@ use strict;
 use warnings;
 package Dancer2::Plugin::RootURIFor;
 {
-    $Dancer2::Plugin::RootURIFor::VERSION = '0.02';
+    $Dancer2::Plugin::RootURIFor::VERSION = '0.03';
 }
 # ABSTRACT: Mountpoint-agnostic uri builder for Dancer2
 
 use URI::Escape;
-use Dancer2 0.15;
-use Dancer2::Plugin;
+use Dancer2::Plugin 0.15;
 
 register root_uri_for => sub {
     my ( $dsl, $part, $params, $dont_escape ) = @_;
-    my $uri = $dsl->request->base;
+    my $uri = $dsl->app->request->base;
 
     $part =~ s{^/*}{/};
     $uri->path("$part");
@@ -37,7 +36,7 @@ Dancer2::Plugin::RootURIFor - Mountpoint-agnostic uri builder for Dancer2
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =head1 SYNOPSIS
 
